@@ -35,7 +35,8 @@ public:
     enum Roles
     {
         UrlRole = Qt::UserRole,
-        NameRole
+        NameRole,
+        PostRole
     };
 
     int rowCount(const QModelIndex&) const;
