@@ -17,13 +17,17 @@
 
 #include "newsfeedpost.h"
 #include "facebookaccount.h"
+#include "newsfeedmodel.h"
 
-NewsFeedPost::NewsFeedPost(QObject *parent, FacebookAccount *account, long long createdTime, const QString &url, const QString &message)
+NewsFeedPost::NewsFeedPost(QObject *parent, FacebookAccount *account, const QString &postId,
+                           long long createdTime, const QString &url, const QString &message)
     : QObject(parent),
     m_createdTime(createdTime),
     m_account(account),
     m_url(url),
-    m_message(message)
+    m_message(message),
+    m_id(postId),
+    m_commentsModel(new NewsFeedModel(this))
 {
     connect(m_account, SIGNAL(modified()), SIGNAL(modified()));
 }
@@ -47,3 +51,13 @@ long long NewsFeedPost::createdTime() const
 {
     return m_createdTime;
 }
+
+const QString &NewsFeedPost::id() const
+{
+    return m_id;
+}
+
+NewsFeedModel *NewsFeedPost::commentsModel() const
+{
+    return m_commentsModel;
+}
